@@ -42,10 +42,11 @@ protected:
 
 private slots:
     void selectedLevelChanged(const QModelIndex &current, const QModelIndex &previous);
+    void levelDataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight);
 
 private:
     void updateDetails(QSharedPointer<Level> level);
-    QString diffString(int difficulty) const;
+    void resetSelection();
 
     Ui::LevelSelectUi *ui;
 
